Clazz.declarePackage("J.g3d");
Clazz.declareInterface(J.g3d, "G3DRenderer");
;//5.0.1-v7 Sat Jan 10 11:40:46 CST 2026
